#ifndef __TET_CONFIG_H__
#define __TET_CONFIG_H__
/*===============================================================*/
/* itetris standard header file configured for Russian support.  */
/*---------------------------------------------------------------*/
/* To view Russian text in this file, you need to set the        */
/* appropriate console font with                                 */
/*          setfont   Cyr_a8x16                                  */
/*                                                               */
/* If you, unlike me, are lucky enough to have appropriate       */
/* keyboard, select keymap with                                  */
/*          loadgzkeys ru2.map                                   */
/* and use right Alt key to toggle between Russian and Latin.    */
/*                                                               */
/* Alternatively, you can grab characters from the list,         */
/* supplied below                                                */
/* YOU DO NOT NEED THE ABOVE COMMAND FOR PLAYING THE GAME.       */
/* The font will be used independently on the system font.       */
/*---------------------------------------------------------------*/
/* N.B! X fonts coming with new RedHat distribution are actually */
/* converted console fonts. It looks like the converter is not   */
/* quite right, so that the letters appear too wide. You can     */
/* comment out line USE_X_FONT=1 in Makefile to use the original */
/* console fonts instead: this looks much better.                */
/*===============================================================*/
#ifdef HAVE_CONFIG_H
#include "tet_autoconf.h"
#else
#include "tet_stdconf.h"
#endif


/* Location of Pause text and Play List */
/* Default location of high scores file is now defined in Makefile */
#define PAUSE_FILE_NAME   "~/.itetris.pause"
#define BGLIST_FILE_NAME  "~/.itetris.bgl"

/* TABLE_WIDTH is the width of score table in char-s (8 pix. per char) */
#define TABLE_WIDTH   14

/* Text and background, highlighting and scroller colour numbers */
/*     See man page for vga_setegacolor.        */
#define TEXT_COLOUR    14        // Yellow
#define BKGR_COLOUR     0        // Black
#define HILITE_COLOUR  13        // Light magenta
#define SCROLL_COLOUR   2        // Green

/* Vertical distance between rows in status table */
#define ROW_DISTANCE   3

/* #define  DEFAULT_FONT  "Cyr_a8x16"      // ISO 8859-5 */
/*  #define DEFAULT_FONT "UniCyr_8x16"     // ISO 8859-5 - unicode */ 
#define  DEFAULT_FONT  "koi8-8x16"	   /* KOI-8 */

/* Don't believe your eyes: these will be an 8p wide font with Redhat */
#define  DEFAULT_X_FONT	"-cronyx-fixed-bold-r-*-*-16-*-72-72-*-60-*-*"
/* The following line should be used with correct cyrrilic font */
// #define  DEFAULT_X_FONT  "-cronyx-fixed-bold-r-*-*-16-*-72-72-*-80-*" KOI-8  

/* Default video mode. Select one of the following:
   EGA_MODE, LOW_MODE,  VGA_MODE,  SVGA_MODE.
   Use VGA_MODE if your SVGA card is not supported or badly
   supported by svgalib
*/
#define  DEFAULT_VIDEO  SVGA_MODE

/* Defines for COLOUR_NAME_FILE, COLOUR_NAME_FILE_ALT and
   DEFAUT_BG_RGB are not used in EGA mode */

/* Path to the file with colour names */
#define COLOUR_NAME_FILE  "/etc/X11/rgb.txt"
/* Alternative file - may be omitted */
#define COLOUR_NAME_FILE_ALT "/usr/lib/X11/rgb.txt"

/* Default RGB for background colour */
#define DEFAULT_BG_RGB   ""          /* Do not set */
/* #define DEFAULT_BG_RGB "03f0000"   - take 0RRGGBB colour */
/* #define DEFAULT_BG_RGB "maroon"   - look in COLOUR_NAME_FILE */

/* Default modes for background music */
#define DEFAULT_MODES   "IOeLk"    /* Redirect stdin, stdout */
                                   /* Do not redirect stderr */
                                   /* Enable loop, disable kill */				  	
/* The following line includes support of wide characters 
   (console version only) */
/* #define WCHAR_SUPPORT */

/* Uncomment this to make life easier to your computer */
/* #define SCROLLER_DISABLED  */

/* Timer ticks needed to load a backround music file (1 sec = 18.2 ticks) */
#define LOAD_DELAY 7
/* Timer ticks needed to wait after pevious player is killed */
#define KILL_DELAY 7

/* Starting Bottom mode B_SCROLLER, B_HELP or B_NONE */
#define START_BOTTOM_DEMO       B_SCROLLER
#define START_BOTTOM_GAME       B_HELP

/* Textmode clear screen sequence (Standard ANSI should always be OK,
   so that you probably should leave it unchanged). */
#define CLEAR_SCREEN "\033[2J"

/* The 256c owl image looks ugly in 16c mode, so you better disable it
   commenting out the following line ... and reduce the size of binary  */
#define SHOW_256C_IMAGE

/*===================================================== */
/*                  J O Y S T I C K                     */
/*                  - - - - - - - -                     */
/*===================================================== */

#ifdef HAVE_LINUX_JOYSTICK_H
/*
   Joystick Linux driver:
   -------------------------------------------------------------------
   Parameter JOYSTICK_DRIVER is set to:
   1 - include event-driven support, provided by driver version 1x.
   0 - include only "traditional" support provided by original driver
   -------------------------------------------------------------------
   Comment out JOYSTICK_DRIVER to disable joystick driver
*/
#define JOYSTICK_DRIVER 1

/* If JOYSTICK_DRIVER = 1, you need the following lines to specify
   the the threshold values for joystick axes (max. 32767)
   E.g. NEW_JOYSTICK_THRESHOLD_X = 10000 means that
     X-axis position <= -10000 is interpreted as joystick left
     X-axis position >= +10000 is interpreted as joystick right
     Position between -10000 and +10000 - no shift along X axis
*/
#define NEW_JOYSTICK_THRESHOLD_X 23000
#define NEW_JOYSTICK_THRESHOLD_Y 23000

#endif   /* def HAVE_LINUX_JOYSTICK_H */

#if defined(X11) && defined(HAVE_X11_EXTENSIONS_XINPUT_H)
/*
   Joystick XInput interface.
   -------------------------------------------------------------------
   It will be attempted, if available for X11 in case
   no Linux driver is found, or Linux driver is disabled
   -------------------------------------------------------------------
   Uncomment out JOYSTICK_XINPUT to enable XInput support
*/
/* #define JOYSTICK_XINPUT */
#endif

/* The following two lines should remain unchanged */
#if defined(JOYSTICK_DRIVER) || defined(JOYSTICK_XINPUT)
#define JOYSTICK_SUPPORTED

/* Default enabled status for joystick
  (applies to any joystick type) */
#define JOY_ENABLED_DEFAULT  0

#endif

/*===================================================== */
/*                  TEXT  STRINGS                       */
/*                  -------------                       */
/*===================================================== */

/* ************************** ISO 8859-5 ************************ */
/*
#define SCORE_TEXT  ":"
#define LEVEL_TEXT  "஢:"
#define LAYERS_TEXT ":"
#define BONUS_TEXT   ":"
#define NEXT_TEXT   ":"
#define JOYSTICK_TEXT "⨪:"
#define TOTAL_TEXT "⮣:"
#define TOP_HEADER "訥 १"
*/
/*
                                
                                
                                
                                
*/

/* ************************** KOI 8 ************************ */

#define SCORE_TEXT  "ޣ:"
#define LEVEL_TEXT  ":"
#define LAYERS_TEXT "ϣ:"
#define BONUS_TEXT   ":"
#define NEXT_TEXT   ":"
#define JOYSTICK_TEXT ""
#define TOTAL_TEXT ":"
#define TOP_HEADER " "

/*
                       
                       
             */
#endif